@@ -13,7 +13,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********/
-// Copyright (c) 1996-2000 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
 // Basic Usage Environment: for a simple, non-scripted, console application
 // Implementation
 
@@ -48,11 +48,17 @@ BasicUsageEnvironment::createNew(TaskScheduler& taskScheduler) {
 
 int BasicUsageEnvironment::getErrno() const {
 #if defined(__WIN32__) || defined(_WIN32)
+#ifndef _WIN32_WCE
   if (errno == 0) {
     errno = WSAGetLastError();
   }
 #endif
+#endif
+#if defined(_WIN32_WCE)
+  return WSAGetLastError();
+#else
   return errno;
+#endif
 }
 
 UsageEnvironment& BasicUsageEnvironment::operator<<(char const* str) {
