@@ -14,35 +14,54 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********/
 /* "groupsock" interface
- * Copyright (c) 1996-2003 Live Networks, Inc.  All rights reserved.
+ * Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
  * Common include files, typically used for networking
  */
 
 #ifndef _NET_COMMON_H
 #define _NET_COMMON_H
 
-#include <string.h>
-
 #if defined(IMN_PIM)
 #include "IMN_PIMNetCommon.h"
-#else
-#if defined(__WIN32__) || defined(_WIN32)
+
+#elif defined(__WIN32__) || defined(_WIN32) || defined(_WIN32_WCE)
 /* Windows */
-#if defined(_WINNT) || defined(__BORLANDC__)
+#if defined(WINNT) || defined(_WINNT) || defined(__BORLANDC__) || defined(__MINGW32__) || defined(_WIN32_WCE)
 #define _MSWSOCK_
 #include <winsock2.h>
 #include <ws2tcpip.h>
 #endif
 #include <windows.h>
+#include <string.h>
 
-#define _close closesocket
+#define closeSocket closesocket
 #define EWOULDBLOCK WSAEWOULDBLOCK
 
+#if defined(_WIN32_WCE)
+#define NO_STRSTREAM 1
+#endif
+
 /* Definitions of size-specific types: */
+typedef __int64 int64_t;
+typedef unsigned __int64 u_int64_t;
 typedef unsigned u_int32_t;
 typedef unsigned short u_int16_t;
 typedef unsigned char u_int8_t;
 
+#elif defined(VXWORKS)
+/* VxWorks */
+#include <time.h>
+#include <timers.h>
+#include <sys/times.h>
+#include <sockLib.h>
+#include <hostLib.h>
+#include <resolvLib.h>
+#include <ioLib.h>
+
+typedef unsigned int u_int32_t;
+typedef unsigned short u_int16_t;
+typedef unsigned char u_int8_t;
+
 #else
 /* Unix */
 #include <sys/types.h>
@@ -52,6 +71,7 @@ typedef unsigned char u_int8_t;
 #include <arpa/inet.h>
 #include <netdb.h>
 #include <unistd.h>
+#include <string.h>
 #include <stdlib.h>
 #include <errno.h>
 #include <strings.h>
@@ -61,15 +81,15 @@ typedef unsigned char u_int8_t;
 #include <unix.h>
 #endif
 
-#define _close close
+#define closeSocket close
 
 #ifdef SOLARIS
+#define u_int64_t uint64_t
 #define u_int32_t uint32_t
 #define u_int16_t uint16_t
 #define u_int8_t uint8_t
 #endif
 #endif
-#endif
 
 #ifndef SOCKLEN_T
 #define SOCKLEN_T int
