@@ -13,7 +13,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********/
-// Copyright (c) 1996-2000, Live Networks, Inc.  All rights reserved
+// Copyright (c) 1996-2008, Live Networks, Inc.  All rights reserved
 // A test program that receives a RTP/RTCP multicast MP3 stream,
 // and outputs the resulting MP3 file stream to 'stdout'
 // main program
@@ -26,7 +26,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 // To receive a stream of 'ADUs' rather than raw MP3 frames, uncomment this:
 //#define STREAM_USING_ADUS 1
 // (For more information about ADUs and interleaving,
-//  see <http://www.live.com/rtp-mp3/>)
+//  see <http://www.live555.com/rtp-mp3/>)
 
 // To receive a "source-specific multicast" (SSM) stream, uncomment this:
 //#define USE_SSM 1
@@ -100,14 +100,14 @@ int main(int argc, char** argv) {
 #endif
 
   // Create (and start) a 'RTCP instance' for the RTP source:
-  const unsigned totalSessionBandwidth = 160; // in kbps; for RTCP b/w share
+  const unsigned estimatedSessionBandwidth = 160; // in kbps; for RTCP b/w share
   const unsigned maxCNAMElen = 100;
   unsigned char CNAME[maxCNAMElen+1];
   gethostname((char*)CNAME, maxCNAMElen);
   CNAME[maxCNAMElen] = '\0'; // just in case
   sessionState.rtcpInstance
     = RTCPInstance::createNew(*env, &rtcpGroupsock,
-			      totalSessionBandwidth, CNAME,
+			      estimatedSessionBandwidth, CNAME,
 			      NULL /* we're a client */, rtpSource);
   // Note: This starts RTCP running automatically
 
